<?php


/* 
 * Retrieves FAQs related to one or more subjects ID 
 *
 * @param (int|array) $subj_id = a single subject term ID or an array of term IDs 
 * @param (array) $custom_args = custom WP_query parameters to customize the query (optional) 
 *
 * @return (array) an array containing matched FAQs array(faq_id => faq_data)
 */
function fr_get_faqs($subj_id, $custom_args = array()) {
    if(!dike_lc('lcweb', 'fr')) {
        return false;   
    }
    
    $def_sorting = get_option('fr_default_sorting', 'name_asc');
    $def_orderby = (strpos($def_sorting, 'name') !== false) ? 'title' : 'ID';
    $def_order   = (strpos($def_sorting, 'asc') !== false) ? 'ASC' : 'DESC';
    
	$args = array(
		'post_type'       => 'fr_faqs', 
		'post_status'     => 'publish', 
		'posts_per_page'  => -1,
		'meta_key'        => 'fr_sort_order',
        'orderby'         => array('meta_value_num' => 'ASC', $def_orderby => $def_order),
        
		//'orderby'		=> 'meta_value_num title',
		//'order'			=> 'ASC',
		
		'tax_query' 		=> array(
			array(
				'taxonomy' 			=> 'fr_faq_subjs',
				'field' 			=> 'id',
				'terms' 			=> $subj_id,
				'include_children' 	=> true
			)
		)
	);
	$args = array_merge($args, $custom_args);

	$query 	= new WP_Query($args);
	$faqs	= (array)$query->posts;
	
	$indexed = array();
	foreach($faqs as $faq) {
		$indexed[ $faq->ID ] = $faq;	
	}
	return $indexed;		
}





/* 
 * Searches FAQs specifying a subject ID and a text string. Search is performed in titles + main text + search helper
 * Minimum string length = 3 characters
 *
 * @param (int|array) $subj_id = a single subject term ID or an array of term IDs 
 * @param (string) $search_txt = string used to match FAQs
 * @param (array) $custom_args = custom WP_query parameters to customize the query (optional) 
 *
 * @return (array) an array containing matched FAQs array(faq_id => faq_data)
 */
function fr_search_faqs($subj_id, $search_txt, $custom_args = array()) {
	if(!dike_lc('lcweb', 'fr')) {
        return false;    
    }
    
	$faqs = fr_get_faqs($subj_id, $custom_args);
	if(empty($faqs)) {
		return array();	
	}
	
	// manage search string 
	$search_txt = strtolower( preg_replace('/[^\p{L}\p{N}\s]/u', '', $search_txt));
	if(strlen($search_txt) < 3) {
		return array();	
	}
	
	
	// prepare FAQ texts
	$faq_txts = array();
	foreach($faqs as $faq_id => $faq_data) {
		
		$faq_txts[$faq_id] = strip_tags(implode(' ', array(
			$faq_data->post_title,
			$faq_data->post_content,
			(string)get_post_meta($faq_data->ID, 'fr_search_helper', true)
		)));
	}
	
	
	
	// match
	$matching = array();
	foreach(explode(' ', $search_txt) as $word) {
		
		foreach($faq_txts as $faq_id => $txt) {
			
			if(!isset($matching[$faq_id]) && stripos($txt, $word) !== false) {	
				$matching[$faq_id] = $faqs[$faq_id];
			}
		}
	}
	
	return $matching;			
}